pub struct UTCDateTime { /* private fields */ }
Represents a Gregorian Date and Time in UTC

Implementations

source

impl UTCDateTime

source

pub fn new(date: Date, time: Time) -> UTCDateTime

New UTC Date and Time

source

pub fn try_from_values( year: i32, month: u8, day: u8, hour: u8, minute: u8, seconds: u8 ) -> Result<UTCDateTime, GreaterThanEqualToValueError<u8>>

New UTC Date and Time from the specified values

source

pub fn try_from_values_f64( year: i32, month: u8, day: u8, hour: u8, minute: u8, seconds: f64 ) -> Result<UTCDateTime, GreaterThanEqualToValueError<f64>>

New UTC date and Time from the specified values (fractional seconds)

source

pub fn get_date(&self) -> Date

Returns the Gregorian Date portion of this UTCDateTime

source

pub fn get_time(&self) -> Time

Returns the Time portion of this UTCDateTime

source

pub fn now() -> UTCDateTime

Returns the current instant in time as reported by the local system clock.

source

pub fn format<T: Format<UTCDateTime>>(&self, format: &T) -> String