#[non_exhaustive]
pub enum DurationUnit { Second, Millisecond, Microsecond, Nanosecond, Minute, Hour, Day, Year, }
Represents a specific duration unit - SI or otherwise.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Second

SI Base Unit for Duration - Second.

The second division of the hour by 60.



Millisecond

A milli-second, one-thousandth of a second (1e-3)



Microsecond

A micro-second, one-millionth of a second (1e-6)



Nanosecond

A nano-second, one-billionth of a second (1e-9)



Minute

A minute, the first division of an hour by 60.



Hour

An hour, 24 in a day.



Day

NIST 811 defines a “Day” as 86400 seconds, without the concept of leap seconds.



Year

NIST 811 defines a “Year” as 365 days, or 31_536_000 seconds, without the concept of leap days.

Implementations

source

impl DurationUnit

source

pub fn as_seconds(self, value: f64) -> f64

Converts the specified value into Seconds

source

pub fn as_millis(self, value: f64) -> f64

Converts the specified value into Milliseconds

source

pub fn as_micros(self, value: f64) -> f64

Converts the specified value into Microseconds

source

pub fn as_nanos(self, value: f64) -> f64

Converts the specified value into Nanoseconds

source

pub fn as_minutes(self, value: f64) -> f64

Converts the specified value into Minutes

source

pub fn as_hours(self, value: f64) -> f64

Converts the specified value into Hours