Timestamp

Struct Timestamp 

pub struct Timestamp<T> { /* private fields */ }
Represents a Duration offset from a particular Epoch

Implementations

Source

impl<T> Timestamp<T>

pub const fn new(epoch: Epoch, duration: Duration) -> Self

pub const fn get_epoch(&self) -> Epoch

Returns the base epoch for this timestamp

pub const fn get_offset(&self) -> Duration

Returns the relative offset of this timestamp from the specified epoch.

Source

impl Timestamp<UnixEpoch>

pub fn now() -> UnixTimestamp

Available on crate feature std only.

Returns the local system clock equivalent of the unix timestamp

pub fn elapsed(&self) -> Duration

Available on crate feature std only.

Returns the local system clock duration since the timestamp. MAY BE NEGATIVE if the clock has changed since the last call.

pub fn as_date(&self) -> Date

Returns this timestamp as a Date

pub fn as_julian(&self) -> JulianDate

Source

impl Timestamp<UnixEpoch>

pub const fn from_offset(offset: Duration) -> UnixTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> UnixTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<GPSEpoch>

pub const fn from_offset(offset: Duration) -> GPSTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> GPSTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<GregorianEpoch>

pub const fn from_offset(offset: Duration) -> GregorianTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> GregorianTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<WindowsEpoch>

pub const fn from_offset(offset: Duration) -> WindowsNTTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<PrimeEpoch>

pub const fn from_offset(offset: Duration) -> PrimeTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> PrimeTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<Leapoch>

pub const fn from_offset(offset: Duration) -> LeapochTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> LeapochTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> LeapochTimestamp

Creates a new timestamp given the specified number of fractional seconds

Source

impl Timestamp<Vicintipoch>

pub const fn from_offset(offset: Duration) -> VicintiTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> VicintiTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> VicintiTimestamp

Creates a new timestamp given the specified number of fractional seconds