UnixTimestamp

Type Alias UnixTimestamp 

pub type UnixTimestamp = Timestamp<UnixEpoch>;
Represents a duration offset from the UNIX_EPOCH.

Aliased Type

pub struct UnixTimestamp { /* private fields */ }

Implementations

Source

impl UnixTimestamp

pub fn now() -> UnixTimestamp

Available on crate feature std only.

Returns the local system clock equivalent of the unix timestamp

pub fn elapsed(&self) -> Duration

Available on crate feature std only.

Returns the local system clock duration since the timestamp. MAY BE NEGATIVE if the clock has changed since the last call.

pub fn as_date(&self) -> Date

Returns this timestamp as a Date

pub fn as_julian(&self) -> JulianDate

Source

impl UnixTimestamp

pub const fn from_offset(offset: Duration) -> UnixTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> UnixTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp

Creates a new timestamp given the specified number of fractional seconds