WindowsNTTimestamp

Type Alias WindowsNTTimestamp 

pub type WindowsNTTimestamp = Timestamp<WindowsEpoch>;
Represents a duration offset from the WINDOWS_NT_EPOCH

Note: when a duration is actually retrieved from the windows FILETIME routines, it comes back in 100-nanosecond increments from this epoch.

Aliased Type

pub struct WindowsNTTimestamp { /* private fields */ }

Implementations

Source

impl WindowsNTTimestamp

pub const fn from_offset(offset: Duration) -> WindowsNTTimestamp

Creates a new timestamp given the specified offset

pub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of seconds

pub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of fractional seconds