pub trait FormatParser {
    type Item;

    // Required method
    fn try_from(&self, data: &str) -> Result<Self::Item, FormatError>;
}
Provides a mechanism to parse a date or time from a string.

Required Associated Types

Required Methods

source

fn try_from(&self, data: &str) -> Result<Self::Item, FormatError>

Tries to parse the specified string into the resultant item.

Implementors