Struct irox_time::Duration

source ·
pub struct Duration { /* private fields */ }

Implementations

source

impl Duration

source

pub const fn new(value: f64, units: DurationUnit) -> Duration

source

pub fn value(&self) -> f64

source

pub fn units(&self) -> DurationUnit

source

impl Duration

source

pub const fn new_seconds(value: f64) -> Duration

Creates a new duration using the specified number of seconds

source

pub fn as_ydhms(&self) -> (u64, u16, u8, u8, u8)

Returns this duration as (Years, Days, Hours, Minutes, Seconds)

source

pub fn as_dhms(&self) -> (u64, u8, u8, u8)

Returns this duration as (Days, Hours, Minutes, Seconds)

source

pub fn as_hms(&self) -> (u64, u8, u8)

Returns this duration as (Hours, Minutes, Seconds)

source

pub fn as_seconds(&self) -> u64

Returns the value of this duration as whole seconds, with any fractional element truncated off.

source

pub fn as_seconds_f64(&self) -> f64

Returns the value of this duration in fractional seconds

source

pub fn as_seconds_f32(&self) -> f32

Returns the value of this duration in fractional seconds

source

pub fn as_millis(&self) -> u64

Returns the value of this duration as whole milliseconds, with any fractional element truncated off.

source

pub fn as_micros(&self) -> u64

Returns the value of this duration as whole microseconds, with any fractional element truncated off.

source

pub fn as_nanos(&self) -> u64

Returns the value of this duration as whole microseconds, with any fractional element truncated off.

source

pub fn as_minutes(&self) -> u64

Returns the value of this duration as whole minutes, with any fractional element truncated off

source

pub fn as_hours(&self) -> u64

Returns the value of this duration as whole hours, with any fractional element truncated off

source

pub fn as_days(&self) -> u64

Returns the value of this duration as whole days, with any fractional element truncated off

source

pub fn as_years(&self) -> u64

Returns the value of this duration as whole years, with any fractional element truncated off

source

impl Duration

source

pub const fn from_micros(micros: u64) -> Duration

Creates a new Duration from the specified number of microseconds.

Examples
use irox_units::units::duration::Duration;

let duration = Duration::from_micros(1_000_002);

assert_eq!(1, duration.as_seconds());
source

pub const fn from_millis(millis: u64) -> Duration

Creates a new Duration from the specified number of milliseconds.

Examples
use irox_units::units::duration::Duration;

let duration = Duration::from_millis(2569);

assert_eq!(2, duration.as_seconds());
source

pub const fn from_nanos(nanos: u64) -> Duration

Creates a new Duration from the specified number of nanoseconds.

Examples
use irox_units::units::duration::Duration;

let duration = Duration::from_nanos(1_000_000_123);

assert_eq!(1, duration.as_seconds());
source

pub const fn from_minutes(minutes: u64) -> Duration

source

pub const fn from_hours(hours: u64) -> Duration

source

pub const fn from_days(days: u64) -> Duration

source

pub const fn from_years(years: u64) -> Duration

source

pub const fn from_seconds(seconds: u64) -> Duration