pub struct Time32 { /* private fields */ }Expand description
32 Bit Fixed Precision Time Format, storing 16 bits of Seconds, and 16 bits
of Fractional Seconds. This is the equivalent of Q16.16, and is semantically
equivalent to the NTP Short Format if using the epoch::NTP_EPOCH.
The 16-bit seconds field can resolve a little over 18 hours, and the 16-bit fractional seconds field can resolve a little over 15 microseconds.
Implementations