pub struct Timestamp<T> { /* private fields */ }Implementations
Sourceimpl Timestamp<UnixEpoch>
impl Timestamp<UnixEpoch>
Sourcepub const fn from_offset(offset: Duration) -> UnixTimestamp
pub const fn from_offset(offset: Duration) -> UnixTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> UnixTimestamp
pub const fn from_seconds(seconds: u32) -> UnixTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
Creates a new timestamp given the specified number of fractional seconds
Sourceimpl Timestamp<GPSEpoch>
impl Timestamp<GPSEpoch>
Sourcepub const fn from_offset(offset: Duration) -> GPSTimestamp
pub const fn from_offset(offset: Duration) -> GPSTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> GPSTimestamp
pub const fn from_seconds(seconds: u32) -> GPSTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp
pub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp
Creates a new timestamp given the specified number of fractional seconds
Sourceimpl Timestamp<GregorianEpoch>
impl Timestamp<GregorianEpoch>
Sourcepub const fn from_offset(offset: Duration) -> GregorianTimestamp
pub const fn from_offset(offset: Duration) -> GregorianTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> GregorianTimestamp
pub const fn from_seconds(seconds: u32) -> GregorianTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp
pub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp
Creates a new timestamp given the specified number of fractional seconds
Sourceimpl Timestamp<WindowsEpoch>
impl Timestamp<WindowsEpoch>
Sourcepub const fn from_offset(offset: Duration) -> WindowsNTTimestamp
pub const fn from_offset(offset: Duration) -> WindowsNTTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp
pub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp
pub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp
Creates a new timestamp given the specified number of fractional seconds
Sourceimpl Timestamp<PrimeEpoch>
impl Timestamp<PrimeEpoch>
Sourcepub const fn from_offset(offset: Duration) -> PrimeTimestamp
pub const fn from_offset(offset: Duration) -> PrimeTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> PrimeTimestamp
pub const fn from_seconds(seconds: u32) -> PrimeTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp
pub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp
Creates a new timestamp given the specified number of fractional seconds