Struct irox_time::epoch::Timestamp

source ·
pub struct Timestamp<T> { /* private fields */ }
Represents a Duration offset from a particular Epoch

Implementations

source

impl<T> Timestamp<T>

source

pub fn get_epoch(&self) -> Epoch

Returns the base epoch for this timestamp

source

pub fn get_offset(&self) -> Duration

Returns the relative offset of this timestamp from the specified epoch.

source

impl Timestamp<UnixEpoch>

source

pub fn now() -> UnixTimestamp

Returns the local system clock equivalent of the unix timestamp

source

pub fn elapsed(&self) -> Duration

Returns the local system clock duration since the timestamp. MAY BE NEGATIVE if the clock has changed since the last call.

source

pub fn as_date(&self) -> Date

Returns this timestamp as a Date

source

impl Timestamp<UnixEpoch>

source

pub const fn from_offset(offset: Duration) -> UnixTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> UnixTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp

Creates a new timestamp given the specified number of fractional seconds

source

impl Timestamp<GPSEpoch>

source

pub const fn from_offset(offset: Duration) -> GPSTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> GPSTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp

Creates a new timestamp given the specified number of fractional seconds

source

impl Timestamp<GregorianEpoch>

source

pub const fn from_offset(offset: Duration) -> GregorianTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> GregorianTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp

Creates a new timestamp given the specified number of fractional seconds

source

impl Timestamp<WindowsEpoch>

source

pub const fn from_offset(offset: Duration) -> WindowsNTTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp

Creates a new timestamp given the specified number of fractional seconds

source

impl Timestamp<PrimeEpoch>

source

pub const fn from_offset(offset: Duration) -> PrimeTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> PrimeTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp

Creates a new timestamp given the specified number of fractional seconds