pub struct Timestamp<T> { /* private fields */ }Implementations
sourceimpl Timestamp<UnixEpoch>
impl Timestamp<UnixEpoch>
sourceimpl Timestamp<UnixEpoch>
impl Timestamp<UnixEpoch>
sourcepub const fn from_offset(offset: Duration) -> UnixTimestamp
pub const fn from_offset(offset: Duration) -> UnixTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> UnixTimestamp
pub const fn from_seconds(seconds: u32) -> UnixTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
Creates a new timestamp given the specified number of fractional seconds
sourceimpl Timestamp<GPSEpoch>
impl Timestamp<GPSEpoch>
sourcepub const fn from_offset(offset: Duration) -> GPSTimestamp
pub const fn from_offset(offset: Duration) -> GPSTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> GPSTimestamp
pub const fn from_seconds(seconds: u32) -> GPSTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp
pub const fn from_seconds_f64(seconds: f64) -> GPSTimestamp
Creates a new timestamp given the specified number of fractional seconds
sourceimpl Timestamp<GregorianEpoch>
impl Timestamp<GregorianEpoch>
sourcepub const fn from_offset(offset: Duration) -> GregorianTimestamp
pub const fn from_offset(offset: Duration) -> GregorianTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> GregorianTimestamp
pub const fn from_seconds(seconds: u32) -> GregorianTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp
pub const fn from_seconds_f64(seconds: f64) -> GregorianTimestamp
Creates a new timestamp given the specified number of fractional seconds
sourceimpl Timestamp<WindowsEpoch>
impl Timestamp<WindowsEpoch>
sourcepub const fn from_offset(offset: Duration) -> WindowsNTTimestamp
pub const fn from_offset(offset: Duration) -> WindowsNTTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp
pub const fn from_seconds(seconds: u32) -> WindowsNTTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp
pub const fn from_seconds_f64(seconds: f64) -> WindowsNTTimestamp
Creates a new timestamp given the specified number of fractional seconds
sourceimpl Timestamp<PrimeEpoch>
impl Timestamp<PrimeEpoch>
sourcepub const fn from_offset(offset: Duration) -> PrimeTimestamp
pub const fn from_offset(offset: Duration) -> PrimeTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> PrimeTimestamp
pub const fn from_seconds(seconds: u32) -> PrimeTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp
pub const fn from_seconds_f64(seconds: f64) -> PrimeTimestamp
Creates a new timestamp given the specified number of fractional seconds