pub type UnixTimestamp = Timestamp<UnixEpoch>;Expand description
Represents a duration offset from the UNIX_EPOCH.
Aliased Type
pub struct UnixTimestamp { /* private fields */ }Implementations
Sourceimpl UnixTimestamp
impl UnixTimestamp
Sourcepub fn now() -> UnixTimestamp
Available on crate feature std only.
pub fn now() -> UnixTimestamp
std only.Returns the local system clock equivalent of the unix timestamp
Sourcepub fn elapsed(&self) -> Duration
Available on crate feature std only.
pub fn elapsed(&self) -> Duration
std only.Returns the local system clock duration since the timestamp. MAY BE NEGATIVE if the clock has changed since the last call.
pub fn as_julian(&self) -> JulianDate
Sourceimpl UnixTimestamp
impl UnixTimestamp
Sourcepub const fn from_offset(offset: Duration) -> UnixTimestamp
pub const fn from_offset(offset: Duration) -> UnixTimestamp
Creates a new timestamp given the specified offset
Sourcepub const fn from_seconds(seconds: u32) -> UnixTimestamp
pub const fn from_seconds(seconds: u32) -> UnixTimestamp
Creates a new timestamp given the specified number of seconds
Sourcepub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
Creates a new timestamp given the specified number of fractional seconds