Type Alias irox_time::epoch::UnixTimestamp
source · pub type UnixTimestamp = Timestamp<UnixEpoch>;Expand description
Represents a duration offset from the UNIX_EPOCH.
Aliased Type
struct UnixTimestamp { /* private fields */ }Implementations
sourceimpl UnixTimestamp
impl UnixTimestamp
sourceimpl UnixTimestamp
impl UnixTimestamp
sourcepub const fn from_offset(offset: Duration) -> UnixTimestamp
pub const fn from_offset(offset: Duration) -> UnixTimestamp
Creates a new timestamp given the specified offset
sourcepub const fn from_seconds(seconds: u32) -> UnixTimestamp
pub const fn from_seconds(seconds: u32) -> UnixTimestamp
Creates a new timestamp given the specified number of seconds
sourcepub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp
Creates a new timestamp given the specified number of fractional seconds