Type Alias irox_time::epoch::UnixTimestamp

source ·
pub type UnixTimestamp = Timestamp<UnixEpoch>;
Represents a duration offset from the UNIX_EPOCH.

Aliased Type

struct UnixTimestamp { /* private fields */ }

Implementations

source

impl UnixTimestamp

source

pub fn now() -> UnixTimestamp

Returns the local system clock equivalent of the unix timestamp

source

pub fn elapsed(&self) -> Duration

Returns the local system clock duration since the timestamp. MAY BE NEGATIVE if the clock has changed since the last call.

source

pub fn as_date(&self) -> Date

Returns this timestamp as a Date

source

impl UnixTimestamp

source

pub const fn from_offset(offset: Duration) -> UnixTimestamp

Creates a new timestamp given the specified offset

source

pub const fn from_seconds(seconds: u32) -> UnixTimestamp

Creates a new timestamp given the specified number of seconds

source

pub const fn from_seconds_f64(seconds: f64) -> UnixTimestamp

Creates a new timestamp given the specified number of fractional seconds